from django.urls import path
from . import views

urlpatterns = (
    path('cidr-table/', views.CIDRTableView.as_view(), name='cidr_table'),
    path('cidr-to-range/', views.CIDRToIpRangeView.as_view(), name='cidr_to_range'),
    path('supernet-calculator/', views.SupernetCalculatorView.as_view(), name='supernet_calculator'),
)


from django.shortcuts import render
from django.views.generic import View
from django.contrib.auth.mixins import LoginRequiredMixin

class CIDRTableView(LoginRequiredMixin, View):
    def get(self, request):
        return render(
            request,
            "netbox_ipv4_tools/cidr.html",
        )

class CIDRToIpRangeView(LoginRequiredMixin, View):
    def get(self, request):
        return render(
            request,
            "netbox_ipv4_tools/cidr-to-range.html",
        )

class SupernetCalculatorView(LoginRequiredMixin, View):
    def get(self, request):
        return render(
            request,
            "netbox_ipv4_tools/supernet-calculator.html",
        )


from pathlib import Path

from setuptools import find_packages, setup

readme = Path(__file__).parent / "README.md"
long_description = readme.read_text()

setup(
    name="netbox-ipv4-tools",
    version="1.0.3",
    description="Work with ipv4 in NetBox",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mlongo4290/netbox-ipv4-tools",
    author="Michael Longo",
    license="Apache 2.0",
    install_requires=[],
    packages=find_packages(),
    include_package_data=True,
    keywords=["netbox-plugin"],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    project_urls={
        "Source": "https://github.com/mlongo4290/netbox-ipv4-tools",
    },
)



from extras.plugins import PluginConfig

class NetBoxIPV4ToolsConfig(PluginConfig):
    name = 'netbox_ipv4_tools'
    verbose_name = ' NetBox IPv4 Tools'
    description = 'Work with ipv4 in NetBox'
    version = '1.0.3'
    base_url = 'ipv4-tools'

config = NetBoxIPV4ToolsConfig


from extras.plugins import PluginMenu, PluginMenuItem

menu = PluginMenu(
    label='IPv4 Tools',
    groups=(
        (
            'TOOLS',
            (
                PluginMenuItem(
                    link='plugins:netbox_ipv4_tools:cidr_table',
                    link_text='CIDR Conversion Table'
                ),
                PluginMenuItem(
                    link='plugins:netbox_ipv4_tools:cidr_to_range',
                    link_text='CIDR to IP Range'
                ),
                PluginMenuItem(
                    link='plugins:netbox_ipv4_tools:supernet_calculator',
                    link_text='Supernet calculator'
                ),
            ),
        ),
    ),
    icon_class='mdi mdi-ip-network',
)